@@ -1,5 +1,4 @@
-"""
-PermissionsX - Authorization for Django.
+"""PermissionsX - Authorization for Django.
 
 :copyright: Copyright (c) 2013-2014 by Robert Pogorzelski.
 :license:   BSD, see LICENSE for more details.
@@ -20,11 +19,12 @@ OVERRIDE_TRUE = 'Override returns True'
 OVERRIDE_FALSE = 'Override returns False'
 
 
-def if_override(x):
-    return(x)
+def if_true_override():
+    return OVERRIDE_TRUE
 
-if_true_override = lambda: if_override(OVERRIDE_TRUE)
-if_false_override = lambda: if_override(OVERRIDE_FALSE)
+
+def if_false_override():
+    return OVERRIDE_FALSE
 
 
 class AuthenticatedPermissions(Permissions):
@@ -54,17 +54,23 @@ class AndStaffSuperuserPermissions(Permissions):
 
 class NegatePermissions(Permissions):
 
-    rules = ~P(user__get_profile__is_public=False) & ~P(user__is_authenticated=False)
+    rules = ~P(user__is_public=False) & ~P(user__is_authenticated=False)
 
 
 class IsPublicPermissions(Permissions):
 
-    rules = P(user__get_profile__is_public=True)
+    rules = P(user__is_public=True)
 
 
 class NestedPermissions(Permissions):
 
-    rules = P(P(user__is_authenticated=True) & P(P(user__is_staff=True) & P(P(user__is_superuser=True) & P(user__username='admin2'))))
+    rules = P(
+        P(user__is_authenticated=True) &
+        P(
+            P(user__is_staff=True) &
+            P(P(user__is_superuser=True) & P(user__username='admin2'))
+        )
+    )
 
 
 class RequestParamPermissions(Permissions):
@@ -95,9 +101,27 @@ class NegatedOverrideIfTrueFalsePermissions(Permissions):
 
 class NestedNegatedOverridePermissions(Permissions):
 
-    rules = P(P(user__is_authenticated=False) & ~P(user__is_authenticated=True, if_true=if_true_override, if_false=if_false_override))
+    rules = P(
+        P(user__is_authenticated=False) &
+        ~P(
+            user__is_authenticated=True,
+            if_true=if_true_override,
+            if_false=if_false_override
+        )
+    )
 
 
 class NestedNegatedPermissions(Permissions):
 
-    rules = P(~P(user__is_authenticated=False) & P(P(user__is_authenticated=True) | ~P(user__is_authenticated=False)))
+    rules = P(
+        ~P(user__is_authenticated=False) &
+        P(
+            P(user__is_authenticated=True) |
+            ~P(user__is_authenticated=False)
+        )
+    )
+
+
+class UserAttributesDependentPermissions(Permissions):
+
+    rules = P(user__username='user_username')
