@@ -1,5 +1,4 @@
-"""
-PermissionsX - Authorization for Django.
+"""PermissionsX - Authorization for Django.
 
 :copyright: Copyright (c) 2013-2014 by Robert Pogorzelski.
 :license:   BSD, see LICENSE for more details.
@@ -7,15 +6,22 @@ PermissionsX - Authorization for Django.
 """
 from __future__ import absolute_import
 
+import json
+
 from django.contrib.auth import login
 from django.core.urlresolvers import reverse
+from django.core.exceptions import ImproperlyConfigured
 
-from permissionsx.contrib.django.views import DjangoViewMixin
+from permissionsx.contrib.django.views import (
+    DjangoViewMixin,
+    RedirectView,
+)
 from permissionsx.models import (
     Arg,
     P,
     Permissions,
 )
+from permissionsx.contrib.django.templatetags import permissions
 from permissionsx.tests.models import TestObject
 from permissionsx.tests.permissions import (
     if_false_override,
@@ -48,7 +54,7 @@ from permissionsx.tests.test_utils import UtilityTestCase
 from permissionsx.tests.views import SimpleGetView
 
 
-class PermissionsDefinitionsTests(UtilityTestCase):
+class PermissionsDefinitionsTestCase(UtilityTestCase):
 
     def test_is_authenticated(self):
         request = self.get_request_for_user(self.user)
@@ -102,7 +108,8 @@ class PermissionsDefinitionsTests(UtilityTestCase):
         self.assertFalse(IsPublicPermissions().check(request_user))
         self.assertFalse(IsPublicPermissions().check(request_admin))
         self.assertFalse(AuthenticatedPermissions().check(request_admin))
-        self.user.get_profile().is_public = True
+        self.user.is_public = True
+        self.user.save()
         self.assertTrue(IsPublicPermissions().check(request_user))
         self.assertFalse(IsPublicPermissions().check(request_admin))
 
@@ -115,8 +122,10 @@ class PermissionsDefinitionsTests(UtilityTestCase):
         self.assertTrue(AuthenticatedPermissions().check(request_admin))
         self.assertFalse(NegatePermissions().check(request_user))
         self.assertFalse(NegatePermissions().check(request_admin))
-        self.user.get_profile().is_public = True
-        self.admin.get_profile().is_public = True
+        self.user.is_public = True
+        self.user.save()
+        self.admin.is_public = True
+        self.admin.save()
         self.assertTrue(NegatePermissions().check(request_user))
         self.assertTrue(NegatePermissions().check(request_admin))
 
@@ -158,12 +167,24 @@ class PermissionsDefinitionsTests(UtilityTestCase):
 
     def test_oneliners(self):
         request = self.get_request_for_user(self.user)
-        self.assertFalse(Permissions(P(user__is_authenticated=True) & P(user__username=request.user.username)).check(request))
+        self.assertFalse(
+            Permissions(
+                P(user__is_authenticated=True) & P(user__username=request.user.username)
+            ).check(request)
+        )
         login(request, self.user)
-        self.assertTrue(Permissions(P(user__is_authenticated=True) | P(user__username='someotheruser')).check(request))
-        Permissions(user_is_authenticated & P(user__is_superuser=True, if_false=if_true_override)).check(request)
+        self.assertTrue(
+            Permissions(
+                P(user__is_authenticated=True) | P(user__username='someotheruser')
+            ).check(request)
+        )
+        Permissions(
+            user_is_authenticated & P(user__is_superuser=True, if_false=if_true_override)
+        ).check(request)
         self.assertEqual(OVERRIDE_TRUE, request.permissionsx_return_overrides[0]())
-        Permissions(user_is_superuser | P(user__is_staff=True, if_false=if_false_override)).check(request)
+        Permissions(
+            user_is_superuser | P(user__is_staff=True, if_false=if_false_override)
+        ).check(request)
         self.assertEqual(OVERRIDE_FALSE, request.permissionsx_return_overrides[0]())
         permissions_tested = Permissions(
             P(user__is_authenticated=True) &
@@ -185,8 +206,16 @@ class PermissionsDefinitionsTests(UtilityTestCase):
         request = self.get_request_for_user(self.user)
         setattr(request, 'user2', self.admin)
         login(request, self.user)
-        self.assertTrue(Permissions(P(user__get_profile__is_attached_to_user=Arg('user'))).check(request))
-        self.assertFalse(Permissions(P(user__get_profile__is_attached_to_user=Arg('user2'))).check(request))
+        self.assertTrue(
+            Permissions(
+                P(user__user_is_user=Arg('user'))
+            ).check(request)
+        )
+        self.assertFalse(
+            Permissions(
+                P(user__user_is_user=Arg('user2'))
+            ).check(request)
+        )
 
     def test_nested_negated(self):
         request_admin = self.get_request_for_user(self.admin)
@@ -201,10 +230,10 @@ class PermissionsDefinitionsTests(UtilityTestCase):
         )
 
 
-class PermissionsDjangoViews(UtilityTestCase):
+class PermissionsDjangoViewsTestCase(UtilityTestCase):
 
     def setUp(self):
-        super(PermissionsDjangoViews, self).setUp()
+        super(PermissionsDjangoViewsTestCase, self).setUp()
         self.test_object = TestObject.objects.create(title='Test!')
 
     def test_authenticated(self):
@@ -214,19 +243,6 @@ class PermissionsDjangoViews(UtilityTestCase):
         response = self.client.get(reverse('authenticated'), follow=True)
         self.assertContains(response, 'Passed')
 
-    def test_get_profile(self):
-        # NOTE: Uses OrStaffSuperuserPermissions == P(user__is_staff=True) | P(user__is_administrator=True)
-        response = self.client.get(reverse('get_profile'), follow=True)
-        self.assertContains(response, 'Login')
-        self.login(self.client, 'user')
-        self.assertContains(response, 'Login')
-        self.login(self.client, 'staff')
-        response = self.client.get(reverse('get_profile'), follow=True)
-        self.assertContains(response, 'Passed')
-        self.login(self.client, 'admin')
-        response = self.client.get(reverse('get_profile'), follow=True)
-        self.assertContains(response, 'Passed')
-
     def test_settings_logout(self):
         with SettingsOverride(PERMISSIONSX_LOGOUT_IF_DENIED=True):
             self.login(self.client, 'user')
@@ -240,6 +256,21 @@ class PermissionsDjangoViews(UtilityTestCase):
             response = self.client.get(reverse('authenticated'), follow=True)
             self.assertContains(response, 'Login2')
 
+    def test_no_redirect_if_authenticated(self):
+        with SettingsOverride(PERMISSIONSX_REDIRECT_URL='/accounts/login2/'):
+            request = self.get_request_for_user(self.user)
+            redirect_url = RedirectView(
+                request=request,
+                redirect_url='/redirected/',
+            ).get_redirect_url()
+            self.assertEqual(redirect_url, '/redirected/?next=/')
+            login(request, self.user)
+            redirect_url = RedirectView(
+                request=request,
+                redirect_url='/redirected/',
+            ).get_redirect_url()
+            self.assertEqual(redirect_url, '/redirected/')
+
     def test_response_class(self):
         response = self.client.get(reverse('response_class'), follow=True)
         self.assertContains(response, 'Access Denied')
@@ -287,6 +318,49 @@ class PermissionsDjangoViews(UtilityTestCase):
         response = self.client.get(reverse('menu'), follow=True)
         self.assertContains(response, 'Staff Menu')
 
+    def test_template_tag_permissions_for_user_attrs_anonymous(self):
+        self.user.username = 'user_username'
+        context = {'request': self.get_request_for_user(self.user)}
+        self.assertFalse(
+            permissions(
+                context,
+                'permissionsx.tests.permissions.UserAttributesDependentPermissions'
+            )
+        )
+
+    def test_template_tag_permissions_for_user_attrs_no_request(self):
+        from django.contrib.auth.models import AnonymousUser
+        self.user.username = 'user_username'
+        context = {'user': AnonymousUser()}
+        self.assertFalse(
+            permissions(
+                context,
+                'permissionsx.tests.permissions.UserAttributesDependentPermissions'
+            )
+        )
+
+    def test_template_tag_permissions_for_user_attrs_authenticated(self):
+        request = self.get_request_for_user(self.user)
+        login(request, self.user)
+        context = {'request': request}
+        self.assertFalse(
+            permissions(
+                context,
+                'permissionsx.tests.permissions.UserAttributesDependentPermissions'
+            )
+        )
+
+        self.user.username = 'user_username'
+        request = self.get_request_for_user(self.user)
+        login(request, self.user)
+        context = {'request': request}
+        self.assertTrue(
+            permissions(
+                context,
+                'permissionsx.tests.permissions.UserAttributesDependentPermissions'
+            )
+        )
+
     def test_combining_permissions(self):
 
         class SomeBasicObjectPermissions(Permissions):
@@ -316,7 +390,10 @@ class PermissionsDjangoViews(UtilityTestCase):
         combined_rules = TestView.permissions.get_combined_rules(request)
         self.assertEqual(
             str(combined_rules),
-            '(&{\'some_object1__title\': \'Some Object 1\'},{\'some_object4__title\': \'Some Object 4\'},{\'some_object2__title\': \'Some Object 2\'},{\'some_object3__title\': \'Some Object 3\'})'
+            '(&{\'some_object1__title\': \'Some Object 1\'},'
+            '{\'some_object4__title\': \'Some Object 4\'},'
+            '{\'some_object2__title\': \'Some Object 2\'},'
+            '{\'some_object3__title\': \'Some Object 3\'})'
         )
 
     def test_combining_permissions_with_none(self):
@@ -337,3 +414,64 @@ class PermissionsDjangoViews(UtilityTestCase):
         response = TestView().dispatch(request)
         self.assertEqual(response.status_code, 200)
         self.assertEqual(request.some_object.title, 'Some Object')
+
+    def test_exception_raised_when_no_permissions(self):
+
+        class TestView(DjangoViewMixin, SimpleGetView):
+            pass
+
+        request = self.factory.get('/')
+        self.assertRaises(ImproperlyConfigured, TestView().dispatch, request)
+
+
+class DjangoDebugToolbarIntegrationTestCase(UtilityTestCase):
+
+    def test_django_debug_toolbar_rendered(self):
+        with SettingsOverride(DEBUG=True):
+            response = self.client.get(reverse('authenticated'), follow=True)
+            self.assertContains(response, 'permissionsx.tests.views.LoginView')
+            self.login(self.client, 'user')
+            response = self.client.get(reverse('authenticated'), follow=True)
+            self.assertContains(
+                response,
+                'permissionsx.tests.permissions.AuthenticatedPermissions'
+            )
+            self.assertContains(
+                response,
+                'user__is_authenticated'
+            )
+
+
+class DjangoTastypieIntegrationTestCase(UtilityTestCase):
+
+    def setUp(self):
+        super(DjangoTastypieIntegrationTestCase, self).setUp()
+        self.test_object = TestObject.objects.create(title='Test!')
+
+    def test_tastypie_authorization_general(self):
+        response = self.client.get('/api/v1/testsuperuser/1/')
+        self.assertEqual(response.status_code, 401)
+        self.login(self.client, 'user')
+        response = self.client.get('/api/v1/testsuperuser/1/')
+        self.assertEqual(response.status_code, 401)
+        self.login(self.client, 'admin')
+        response = self.client.get('/api/v1/testsuperuser/1/')
+        self.assertEqual(response.status_code, 200)
+        self.assertContains(response, 'Test!')
+
+    def test_tastypie_authorization_overrides(self):
+        json_data = json.dumps({'title': 'Changed!'})
+        response = self.client.put(
+            '/api/v1/testoverride/1/',
+            json_data,
+            content_type='application/json'
+        )
+        self.assertEqual(response.status_code, 401)
+        self.login(self.client, 'user')
+        response = self.client.put(
+            '/api/v1/testoverride/1/',
+            json_data,
+            content_type='application/json'
+        )
+        self.assertEqual(response.status_code, 204)
+        self.assertEqual(TestObject.objects.get(id=1).title, 'Changed!')
