@@ -1,5 +1,4 @@
-"""
-PermissionsX - Authorization for Django.
+"""PermissionsX - Authorization for Django.
 
 :copyright: Copyright (c) 2013-2014 by Robert Pogorzelski.
 :license:   BSD, see LICENSE for more details.
@@ -14,10 +13,10 @@ def get_class(module_name, cls_name):
     try:
         module = importlib.import_module(module_name)
     except ImportError:
-        raise ImportError('Cannot import class "{}"'.format('.'.join((module_name, cls_name))))
+        raise ImportError('Cannot import class "{0}"'.format('.'.join((module_name, cls_name))))
     try:
         cls = getattr(module, cls_name)
     except AttributeError:
-        raise ImportError('Class "{}" not found in {}'.format(cls_name, module_name))
+        raise ImportError('Class "{0}" not found in {1}'.format(cls_name, module_name))
     else:
         return cls
